pub enum LiteralType {
Show 28 variants
Boolean(bool),
I8(i32),
I16(i32),
I32(i32),
I64(i64),
Fp32(f32),
Fp64(f64),
String(String),
Binary(Vec<u8>),
Date(i32),
IntervalYearToMonth(IntervalYearToMonth),
IntervalDayToSecond(IntervalDayToSecond),
IntervalCompound(IntervalCompound),
FixedChar(String),
VarChar(VarChar),
FixedBinary(Vec<u8>),
Decimal(Decimal),
PrecisionTime(PrecisionTime),
PrecisionTimestamp(PrecisionTimestamp),
PrecisionTimestampTz(PrecisionTimestamp),
Struct(Struct),
Map(Map),
Uuid(Vec<u8>),
Null(Type),
List(List),
EmptyList(List),
EmptyMap(Map),
UserDefined(UserDefined),
}Variants
Boolean(bool)
I8(i32)
I16(i32)
I32(i32)
I64(i64)
Fp32(f32)
Fp64(f64)
String(String)
Binary(Vec<u8>)
Date(i32)
Date in units of days since the UNIX epoch.
IntervalYearToMonth(IntervalYearToMonth)
IntervalDayToSecond(IntervalDayToSecond)
IntervalCompound(IntervalCompound)
FixedChar(String)
VarChar(VarChar)
FixedBinary(Vec<u8>)
Decimal(Decimal)
PrecisionTime(PrecisionTime)
Time in precision units past midnight.
PrecisionTimestamp(PrecisionTimestamp)
PrecisionTimestampTz(PrecisionTimestamp)
Struct(Struct)
Map(Map)
Uuid(Vec<u8>)
Null(Type)
a typed null literal
List(List)
EmptyList(List)
EmptyMap(Map)
UserDefined(UserDefined)
Implementations
Sourceimpl LiteralType
impl LiteralType
Sourcepub fn merge(
field: &mut Option<LiteralType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<LiteralType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.